| Title: | Calculate the Proportion of Permutations in Line with an Informative Hypothesis |
|---|---|
| Description: | Allows for the easy computation of complexity: the proportion of the parameter space in line with the hypothesis by chance. The package comes with a Shiny application in which the calculations can be conducted as well. |
| Authors: | M. A. J. Zondervan-Zwijnenburg |
| Maintainer: | M. A. J. Zondervan-Zwijnenburg <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.1.2 |
| Built: | 2026-05-14 06:38:12 UTC |
| Source: | https://github.com/cran/complexity |
Calculates the complexity for the hypothesis of interest.
complexity(npar,...)complexity(npar,...)
npar |
a value indicating the number of parameters |
... |
an unlimited amount of pairs of parameter indicators that represent constraints, where the first parameter indicator is constrained to be lower than the second parameter indicator. |
A print of the following:
true permutations |
a print of the permutations in line with the constraints |
total number of permutations |
the total number of permutations |
number true |
the number of true permutations |
complexity (proportion) |
the complexity, that is: the proportion of true permutations |
complexity(4,1,2,2,3,3,4)complexity(4,1,2,2,3,3,4)
Launches a Shiny application for the complexity function.
runShiny()runShiny()
A print of the following:
true permutations |
a print of the permutations in line with the constraints |
total number of permutations |
the total number of permutations |
number true |
the number of true permutations |
complexity (proportion) |
the complexity, that is: the proportion of true permutations |